##  How is it useful?
Continuing the example from the application matrix reports, matrix reports are useful for several reasons:
  1. Rationalization and optimization: The report helps easily identify which applications are redundant across different user groups or in a different location and thereby supports application rationalization decisions. It also helps to determine which applications have the potential for increased adoption to enhance standardization and efficiency.
  2. Manage risks: Identify risks across regions and business capabilities for applications by visually depicting the IT components which will soon be end of life
  3. Prioritization: The report helps IT leaders decide which projects and investments are most important for the organization's success, say, for example, in identifying projects of significant business value that belong to specific business capabilities and providers.
